pub struct PublicEncryptionKey {
pub supported_symm_alg: SymmAlgorithm,
pub public_key: BasePublicEncryptionKey,
}Expand description
Specifies a public encryption key and its associated symmetric algorithm used for bulk data encryption when encrypting for that public key.
Canonicalization
Subject to canonicalization for operations specified in 6.1.2 when appearing in:
HeaderInfoToBeSignedCertificate
Canonicalization applies to the BasePublicEncryptionKey. See respective type
definitions for specific canonicalization operations.
Fields
supported_symm_alg: SymmAlgorithmpublic_key: BasePublicEncryptionKeyImplementations
Sourceimpl PublicEncryptionKey
impl PublicEncryptionKey
Sourcepub fn builder() -> PublicEncryptionKeyBuilder
pub fn builder() -> PublicEncryptionKeyBuilder
Create an instance of PublicEncryptionKey using the builder syntax