#[non_exhaustive]pub enum VerificationKeyIndicator {
VerificationKey(PublicVerificationKey),
ReconstructionValue(EccP256CurvePoint),
}Expand description
Contains either verification key or reconstruction value depending on certificate type.
Variants
-
VerificationKey: For explicit certificates- Contains public key for verifying holder’s signatures
-
ReconstructionValue: For implicit certificates- Contains value for recovering public key (per SEC 4 and 5.3.2)
Critical Information Field
This is a critical information field as defined in 5.2.5:
- An implementation that does not recognize the indicated CHOICE when verifying a signed SPDU shall indicate that the SPDU is invalid (per 4.2.2.3.2)
- Invalid in this context means its validity cannot be established
Canonicalization
Subject to canonicalization for operations specified in 6.1.2:
- Applies to
PublicVerificationKeyandEccP256CurvePoint EccP256CurvePointmust be in compressed form:- Choice must be either
compressed-y-0orcompressed-y-1
- Choice must be either
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
VerificationKey(PublicVerificationKey)
ReconstructionValue(EccP256CurvePoint)