pub struct ContributedExtensionBlock<T: HeaderInfoContributedExtension> {
pub contributor_id: HeaderInfoContributorId,
pub extns: SequenceOf<T::Extn>,
}Expand description
Defines the format of an extension block provided by an identified contributor.
Uses the template from IEEE1609DOT2-HEADERINFO-CONTRIBUTED-EXTENSION class
constraint applied to objects in Ieee1609Dot2HeaderInfoContributedExtensions.
Fields
contributor_id: Uniquely identifies the contributorextns: List of extensions from that contributor- Extensions typically follow format specified in section 6.5, but this is not required
Fields
contributor_id: HeaderInfoContributorIdextns: SequenceOf<T::Extn>Trait Implementations
Sourceimpl<T: HeaderInfoContributedExtension + AsnType> AsnType for ContributedExtensionBlock<T>
impl<T: HeaderInfoContributedExtension + AsnType> AsnType for ContributedExtensionBlock<T>
Sourceconst IDENTIFIER: Identifier
const IDENTIFIER: Identifier
Identifier of an ASN.1 type as specified in the original specification
if not identical with the identifier of
SelfSourceconst TAG_TREE: TagTree = _
const TAG_TREE: TagTree = _
The root of this type’s tree of tag’s if it a CHOICE type, otherwise its
Leaf that points Self::TAG.Sourceconst CONSTRAINTS: Constraints = Constraints::NONE
const CONSTRAINTS: Constraints = Constraints::NONE
The set of constraints for values of the given type.
Sourceconst IS_CHOICE: bool = false
const IS_CHOICE: bool = false
Whether the type is choice type. PER/OER encoding rules require this knowledge.
Sourcefn is_present(&self) -> bool
fn is_present(&self) -> bool
Sourceimpl<T: Clone + HeaderInfoContributedExtension> Clone for ContributedExtensionBlock<T>
impl<T: Clone + HeaderInfoContributedExtension> Clone for ContributedExtensionBlock<T>
Sourcefn clone(&self) -> ContributedExtensionBlock<T>
fn clone(&self) -> ContributedExtensionBlock<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: HeaderInfoContributedExtension + AsnType> Constructed<2> for ContributedExtensionBlock<T>
impl<T: HeaderInfoContributedExtension + AsnType> Constructed<2> for ContributedExtensionBlock<T>
Sourceimpl<T: Debug + HeaderInfoContributedExtension> Debug for ContributedExtensionBlock<T>
impl<T: Debug + HeaderInfoContributedExtension> Debug for ContributedExtensionBlock<T>
Sourceimpl<T: HeaderInfoContributedExtension + Decode> Decode for ContributedExtensionBlock<T>
impl<T: HeaderInfoContributedExtension + Decode> Decode for ContributedExtensionBlock<T>
Sourcefn decode_with_tag_and_constraints<_DECODER: Decoder>(
decoder: &mut _DECODER,
tag: Tag,
constraints: Constraints,
) -> Result<Self, _DECODER::Error>
fn decode_with_tag_and_constraints<_DECODER: Decoder>( decoder: &mut _DECODER, tag: Tag, constraints: Constraints, ) -> Result<Self, _DECODER::Error>
Decode this value implicitly tagged with
tag from a given ASN.1
decoder with a set of constraints on what values of that type are allowed. Read moreSourcefn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder. Read more
Sourcefn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_tag<D>(
decoder: &mut D,
tag: Tag,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value implicitly tagged with
tag from a given ASN.1 decoder. Read moreSourcefn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
fn decode_with_constraints<D>(
decoder: &mut D,
constraints: Constraints,
) -> Result<Self, <D as Decoder>::Error>where
D: Decoder,
Decode this value from a given ASN.1 decoder with a set of constraints
on what values of that type are allowed. Read more
Sourceimpl<T: HeaderInfoContributedExtension + Encode> Encode for ContributedExtensionBlock<T>
impl<T: HeaderInfoContributedExtension + Encode> Encode for ContributedExtensionBlock<T>
Sourcefn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>(
&self,
encoder: &mut _ENCODER,
tag: Tag,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), _ENCODER::Error>
fn encode_with_tag_and_constraints<'encoder, _ENCODER: Encoder<'encoder>>( &self, encoder: &mut _ENCODER, tag: Tag, constraints: Constraints, identifier: Identifier, ) -> Result<(), _ENCODER::Error>
Encode this value with
tag into the given crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode<'b, E>(
&self,
encoder: &mut E,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_identifier<'b, E>(
&self,
encoder: &mut E,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_tag_and_identifier<'b, E>(
&self,
encoder: &mut E,
tag: Tag,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Sourcefn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with the
constraints the values this is allowed to encode into. Read moreSourcefn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
fn encode_with_constraints_and_identifier<'b, E>(
&self,
encoder: &mut E,
constraints: Constraints,
identifier: Identifier,
) -> Result<(), <E as Encoder<'b>>::Error>where
E: Encoder<'b>,
Encode this value into the given
crate::Encoder with identifier and the
constraints the values this is allowed to encode into. Read moreSourceimpl<T: Hash + HeaderInfoContributedExtension> Hash for ContributedExtensionBlock<T>
impl<T: Hash + HeaderInfoContributedExtension> Hash for ContributedExtensionBlock<T>
Sourceimpl<T: PartialEq + HeaderInfoContributedExtension> PartialEq for ContributedExtensionBlock<T>
impl<T: PartialEq + HeaderInfoContributedExtension> PartialEq for ContributedExtensionBlock<T>
Sourcefn eq(&self, other: &ContributedExtensionBlock<T>) -> bool
fn eq(&self, other: &ContributedExtensionBlock<T>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<T: Eq + HeaderInfoContributedExtension> Eq for ContributedExtensionBlock<T>
impl<T: HeaderInfoContributedExtension> StructuralPartialEq for ContributedExtensionBlock<T>