pub struct EncryptedData {
pub recipients: SequenceOfRecipientInfo,
pub ciphertext: SymmetricCiphertext,
}Expand description
Encodes data encrypted to one or more recipients using their public or symmetric keys as specified in 5.3.4.
Fields
-
recipients: One or moreRecipientInfoentries- May contain multiple types of
RecipientInfo - All entries must indicate/contain the same data encryption key
- May contain multiple types of
-
ciphertext: Encrypted data- Contains encrypted
Ieee1609Dot2Datastructure (per 5.3.4.2)
- Contains encrypted
Critical Information Fields
The recipients field is critical (per 5.2.6):
- Implementation must support specified number of
RecipientInfoentries - Must support at least eight entries
- Failure to support required number results in decryption failure
Raw Data Example
For plaintext that isn’t from previous SDS operation, it can be encapsulated
in Ieee1609Dot2Data of type unsecuredData (per 4.2.2.2.2):
Raw data: 01 23 45 67 89 AB CD EF
COER encoded: 03 80 08 01 23 45 67 89 AB CD EF
Where:
- 03: protocolVersion
- 80: choice unsecuredData
- 08: length of raw dataFields
recipients: SequenceOfRecipientInfociphertext: SymmetricCiphertextImplementations
Sourceimpl EncryptedData
impl EncryptedData
Sourcepub fn builder() -> EncryptedDataBuilder
pub fn builder() -> EncryptedDataBuilder
Create an instance of EncryptedData using the builder syntax