delegate

Macro delegate 

macro_rules! delegate {
    ($from_type:ty, $to_type:ty) => { ... };
}
A macro to implement From and Deref for a delegate type pair. This is not suitable for newtypes with inner constraints.